<?php

namespace MauticPlugin\MauticMailketingBundle\Swiftmailer\Callback;

use Mautic\EmailBundle\Model\TransportCallback;
use MauticPlugin\MauticMailketingBundle\Swiftmailer\Exception\ResponseItemException;
use Symfony\Component\HttpFoundation\Request;
use Monolog\Logger;
use Symfony\Component\HttpKernel\Exception\HttpException;
use Mautic\EmailBundle\MonitoredEmail\Exception\BounceNotFound;
use Mautic\EmailBundle\MonitoredEmail\Exception\UnsubscriptionNotFound;
use Mautic\EmailBundle\MonitoredEmail\Message;
use Mautic\EmailBundle\MonitoredEmail\Processor\Bounce\BouncedEmail;
use Mautic\EmailBundle\MonitoredEmail\Processor\Bounce\Definition\Category;
use Mautic\EmailBundle\MonitoredEmail\Processor\Bounce\Definition\Type;
use Mautic\EmailBundle\MonitoredEmail\Processor\Unsubscription\UnsubscribedEmail;
use Mautic\LeadBundle\Entity\DoNotContact;

/**
 * Class MailketingApiCallback.
 */
class MailketingApiCallback
{

    /**
     * @var TransportCallback
     */
    private $transportCallback;

    /**
     * @var Logger
     */
    protected $logger;

    /**
     * MailketingApiCallback constructor.
     *
     * @param TransportCallback $transportCallback
     * @param Logger $logger
     */
    public function __construct(TransportCallback $transportCallback, Logger $logger)
    {
        $this->transportCallback = $transportCallback;
        $this->logger = $logger;
    }

    /**
     * Processes Mailketing API callback request.
     *
     * @param Request $request
     */
    public function processCallbackRequest(Request $request)
    {

      $payload = json_decode($request->getContent(), true);

      if (0 !== json_last_error()) {
          throw new HttpException(400, 'Mailketing: Invalid JSON Payload');
      }

      if (!isset($payload['type']) && !isset($payload['email'])) {
          throw new HttpException(400, "Data Kosong");
      }

      $type=$payload['type'];
      echo $payload['email'];
      switch ($type) {
          case 'unsubscribe':
                $this->transportCallback->addFailureByAddress($payload['email'], 'Unsubscribe', DoNotContact::UNSUBSCRIBED);
          break;
          case 'bounce':
                $this->transportCallback->addFailureByAddress($payload['email'], $payload['reason'], DoNotContact::BOUNCED, null);
          break;

        }
    }

}
